@@ -1685,7 +1685,7 @@ AppleUSBHub::CheckForDeadHubEntry(OSObject *target)
     
     if (!me)
         return;
-     
+        
     me->CheckForDeadHub();
     me->DecrementOutstandingIO();
 }
@@ -1697,6 +1697,8 @@ AppleUSBHub::CheckForDeadHub()
 {
     IOReturn			err = kIOReturnSuccess;
     
+    IncrementOutstandingIO();
+    
     // Are we still connected?
     //
     if ( _device )
@@ -1708,9 +1710,7 @@ AppleUSBHub::CheckForDeadHub()
             _hubIsDead = TRUE;
             USBLog(3, "%s[%p]: Detected an kIONotResponding error but still connected.  Resetting port", getName(), this);
             
-            retain();
             ResetMyPort();
-            release();
             
         }
         else
@@ -1723,6 +1723,7 @@ AppleUSBHub::CheckForDeadHub()
         }
     }
 
+    DecrementOutstandingIO();
 }
 
 //=============================================================================================
