@@ -117,7 +117,6 @@ protected:
     IOUSBRootHubDevice *	_rootHubDevice;
     UInt32			_devZeroLock;
     static UInt32		_busCount;
-    static bool			gUsedBusIDs[16];
     
     struct ExpansionData 
     {
@@ -1013,7 +1012,7 @@ public:
                                                         IOMemoryDescriptor *	pBuffer,
                                                         UInt32			frameCount,
                                                         IOUSBLowLatencyIsocFrame *pFrames,
-                                                        UInt32			updateFrequency);
+                                                        UInt32			updateFrequency) = 0;
 
 
     OSMetaClassDeclareReservedUnused(IOUSBController,  17);
