@@ -250,6 +250,8 @@ typedef struct IOUSBLowLatencyIsocCompletion {
     void *				parameter;
 } IOUSBLowLatencyIsocCompletion;
 
+typedef struct IOUSBLowLatencyIsocCompletion IOUSBLowLatencyIsocCompletion;
+
 /* ************* USB Family error codes ************* */
 
 #define	iokit_usb_err(return) (sys_iokit|sub_iokit_usb|return)
@@ -674,7 +676,7 @@ struct LowLatencyUserBufferInfo {
     void *			bufferAddress;
     IOByteCount			bufferSize;
     UInt32			bufferType;
-    Boolean			isPrepared;
+    bool			isPrepared;
     LowLatencyUserBufferInfo *	nextBuffer;
 };
 
